==> states_rebuilder-1.15.0.tar.gz: example/lib/examples/counter_app_with_refresh_indicator.dart <==
import 'package:flutter/material.dart';
import 'package:states_rebuilder/states_rebuilder.dart';

class Counter {
  int _count = 0;
  List<int> count = [];

  increment() async {
    //Simulating async task
    await Future.delayed(Duration(seconds: 1));
    _count++;
    count.add(_count);
  }
}

class App extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Injector(
      inject: [Inject<Counter>(() => Counter())],
      builder: (BuildContext context) {
        final ReactiveModel<Counter> counterModelRM = RM.get<Counter>();
        return Scaffold(
          appBar: AppBar(
            title: Text(" Counter App with refresh indicator"),
          ),
          body: MyHome(),
          floatingActionButton: FloatingActionButton(
            child: Icon(Icons.add),
            onPressed: () => counterModelRM.setState(
              (state) => state.increment(),
            ),
          ),
        );
      },
    );
  }
}

class MyHome extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final counterModel = RM.get<Counter>(context: context);
    return Center(
      child: RefreshIndicator(
        onRefresh: () async {
          await counterModel.setState((state) => state.increment());
        },
        child: ListView(
          children: <Widget>[
            Text("pull down to refresh the list"),
            for (final count in counterModel.state.count)
              Text(
                "$count",
                style: TextStyle(fontSize: 50),
              ),
          ],
        ),
      ),
    );
  }
}

==> states_rebuilder-2.0.0.tar.gz: example/lib/examples/counter_app_with_refresh_indicator.dart <==
import 'package:flutter/material.dart';
import 'package:states_rebuilder/states_rebuilder.dart';

class Counter {
  int _count = 0;
  List<int> count = [];

  increment() async {
    //Simulating async task
    await Future.delayed(Duration(seconds: 1));
    _count++;
    count.add(_count);
  }
}

class App extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Injector(
      inject: [Inject<Counter>(() => Counter())],
      builder: (BuildContext context) {
        final ReactiveModel<Counter> counterModelRM = RM.get<Counter>();
        return Scaffold(
          appBar: AppBar(
            title: Text(" Counter App with refresh indicator"),
          ),
          body: MyHome(),
          floatingActionButton: FloatingActionButton(
            child: Icon(Icons.add),
            onPressed: () => counterModelRM.setState(
              (state) => state.increment(),
            ),
          ),
        );
      },
    );
  }
}

class MyHome extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final counterModel = RM.get<Counter>();
    return StateBuilder(
        observe: () => counterModel,
        builder: (context, __) {
          return Center(
            child: RefreshIndicator(
              onRefresh: () async {
                await counterModel.setState((state) => state.increment());
              },
              child: ListView(
                children: <Widget>[
                  Text("pull down to refresh the list"),
                  for (final count in counterModel.state.count)
                    Text(
                      "$count",
                      style: TextStyle(fontSize: 50),
                    ),
                ],
              ),
            ),
          );
        });
  }
}
